#!/usr/bin/tclsh

package require http

proc RSS_Fetch {url} {
    set tok [http::geturl $url]
    set res [http::data $tok]
    http::cleanup $tok
    return $res
}

proc RSS_UTFtoCP949 {data} {
    set data [encoding convertfrom cp949 $data]
    return $data
}

proc RSS_ReadTitle {data} {
    regexp {<title>(.*?)</title>} $data -> title
    return $title
}

proc RSS_ReadDescription {data} {
    regexp {<description>(.*?)</description>} $data -> description
    return $description
}

proc RSS_UTCtoKST {UTC} {
    regexp {^(20[0-9][0-9])-([0-9][0-9])-([0-9][0-9])T([0-9][0-9]):([0-9][0-9])*} $UTC -> Year Month Date Hour Minute

    # Set data format to calculatable thing
    scan $Year %d Year
    scan $Month %d Month
    scan $Date %d Date
    scan $Hour %d Hour
    scan $Minute %d Minue

    # KST = UTC + 9hour
    set Hour [expr $Hour + 9]

    # Correction for +9hour
    if {$Hour >= 24} {
	set Hour [expr $Hour - 24]
	incr Date
    }
    if {$Date == 29} {
	#If it's febrary, and not leap-year, move to March.
	if {$Month == 2} {
	    if {[expr $Year % 4] == 0} {
		if {[expr $Year % 100] == 0 && [expr $Year % 400] != 0} {
		    # It's not leap year's 02-29
		    set Date  1
		    set Month  3
		} else {
		    # It's leap year.
		}
	    } else {
		# It's not leap year's 02-29
		set Date  1
		set Month  3
	    }

	}
    } elseif {$Date == 30} {
	#If it's febrary, and leap-year, move to March.
	if {$Month == 2} {
	    set Date  1
	    set Month  3
	}
    } elseif {$Date == 31} {
	#check the month which has 30 days; 4/6/9/11
	if {$Month == 4 || $Month == 6 || $Month == 9 || $Month == 11} {
	    set Date 1
	    incr Month
	}
    } elseif {$Date == 32} {
	#increase the month always
	set Date 1
	incr Month
    }
    if {$Month == 13} {
	set Month 1
	incr Year
    }

    # Set data format to printable format: 2figures month/date/hour/minute
    set Month [ format "%02d" $Month ]
    set Date [ format "%02d" $Date ]
    set Hour [ format "%02d" $Hour ]
    set Minute [ format "%02d" $Minute ]

    set KST "$Year-$Month-$Date $Hour:$Minute"

    return $KST
}


set data [RSS_Fetch "http://jangnan.st/moniwiki/wiki.php/RecentChanges?action=rss_rc"]
set data [RSS_UTFtoCP949 $data]
set title [RSS_ReadTitle $data]
set description [RSS_ReadDescription $data]

foreach {- item} [regexp -all -inline {<item (.*?)</item>} $data] {
    #     puts "======================"
    #     puts $item
    #     puts "======================"

    regexp {<title>(.*?)</title>} $item -> title_temp
    regexp {<dc:date>(.*?)</dc:date>} $item -> date_temp
    regexp {<dc:creator>(.*?)</dc:creator>} $item -> writer_temp

    set date_temp [RSS_UTCtoKST $date_temp]

    lappend list_jangnan_recently "\[$title_temp\] by $writer_temp on $date_temp "
}

#puts $list_jangnan_recently